macro_rules! cli_bail {
($msg:literal) => { ... };
($err:expr $(,)?) => { ... };
($fmt:expr, $($arg:tt)*) => { ... };
}Expand description
Return early with an error if a condition is not satisfied.
macro_rules! cli_bail {
($msg:literal) => { ... };
($err:expr $(,)?) => { ... };
($fmt:expr, $($arg:tt)*) => { ... };
}Return early with an error if a condition is not satisfied.